@@ -38,11 +38,19 @@
             yr <- range(unlist(out$gcv.grid[, 3:5]), na.rm = TRUE)
             plot(out$gcv.grid[, 2], out$gcv.grid[, 3], xlab = "Eff. number of parameters", 
                 ylab = " GCV function", bty = "n", ylim = yr, 
-                log = "y", ...)
-            lines(out$gcv.grid[, 2], out$gcv.grid[, 4], lty = 2)
+             
+                 ...)
+            lines(out$gcv.grid[, 2], out$gcv.grid[, 4], lty = 3)
             lines(out$gcv.grid[, 2], out$gcv.grid[, 5], lty = 1)
-            xline(out$eff.df)
-            title("GCV-points , solid- GCV model,\ndashed- GCV one", 
+            xline(out$eff.df, lwd=2, col="grey")
+            usr.save<- par()$usr
+            usr.save[3:4]<- range( -out$gcv.grid[,7] )
+            par( usr= usr.save, ylog=FALSE)
+            lines( out$gcv.grid[, 2], -out$gcv.grid[,7] ,
+            lty=2, lwd=2, col="blue")
+            axis( side=4)
+            mtext( side=4, line=3, "log profile likelihood ")
+            title("GCV-points, solid-model, dots- single  \n REML dashed", 
                 cex = 0.6)
             box()
         }
